django-registration 2.3 — django-registration 2.3 documentation

# django-registration 2.3

django-registration is an extensible application providing user registration functionality for Django-powered Web sites.

Although nearly all aspects of the registration process are customizable, out-of-the-box support is provided for two common use cases:

- Two-phase registration, consisting of initial signup followed by a confirmation email with instructions for activating the new account.
- One-phase registration, where a user signs up and is immediately active and logged in.

To get up and running quickly, consult the quick start guide, which describes the steps necessary to configure django-registration for the built-in workflows. For more detailed information, including how to customize the registration process (and support for alternate registration systems), read through the documentation listed below.

Installation and configuration

- Installation guide
- Quick start guide

Built-in registration workflows

- The HMAC activation workflow
- The one-step workflow
- The model-based activation workflow

For developers

- Base view classes
- Base form classes
- Custom user models
- Validation utilities
- Custom settings
- Signals used by django-registration
- Feature and API deprecation cycle

Other documentation

- Upgrading from previous versions
- Frequently-asked questions

See also

- Django’s authentication documentation. Django’s authentication system is used by django-registration’s default configuration.